#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
# define _cffi_float_complex_t   _Fcomplex    /* include <complex.h> for it */
# define _cffi_double_complex_t  _Dcomplex    /* include <complex.h> for it */
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
# define _cffi_float_complex_t   float _Complex
# define _cffi_double_complex_t  double _Complex
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/


    #include <fcntl.h>
    #include <linux/poll.h>
    #include <linux/types.h>
    #include <sys/socket.h>
    #include <sys/types.h>
    #include <sys/un.h>
    #include <sys/uio.h>
    #include <netinet/in.h>
    #include <unistd.h>
    #include <Python.h>
    #include "liburing.h"

    int io_uring_wait_cqe_nogil(struct io_uring *ring, struct io_uring_cqe **cqe_ptr) {
        int res;
        Py_BEGIN_ALLOW_THREADS
        res = io_uring_wait_cqe(ring, cqe_ptr);
        Py_END_ALLOW_THREADS
        return res;
    }

    int io_uring_wait_cqe_timeout_nogil(struct io_uring *ring, struct io_uring_cqe **cqe_ptr,
                                       struct __kernel_timespec *ts) {
        int res;
        Py_BEGIN_ALLOW_THREADS
        res = io_uring_wait_cqe_timeout(ring, cqe_ptr, ts);
        Py_END_ALLOW_THREADS
        return res;
    }
    

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 29), // int()(struct io_uring *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 127), // struct io_uring *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 29), // int()(struct io_uring *, struct io_uring_cqe * *)
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_POINTER, 25), // struct io_uring_cqe * *
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION, 29), // int()(struct io_uring *, struct io_uring_cqe * *, struct __kernel_timespec *)
/*  8 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  9 */ _CFFI_OP(_CFFI_OP_NOOP, 5),
/* 10 */ _CFFI_OP(_CFFI_OP_POINTER, 124), // struct __kernel_timespec *
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION, 29), // int()(unsigned int, struct io_uring *, unsigned int)
/* 13 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 14 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 15 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // struct io_uring_sqe *()(struct io_uring *)
/* 18 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 19 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring *)
/* 21 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 23 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring *, struct io_uring_cqe *)
/* 24 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 25 */ _CFFI_OP(_CFFI_OP_POINTER, 129), // struct io_uring_cqe *
/* 26 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 27 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, int64_t, int, int64_t, unsigned int, unsigned int)
/* 28 */ _CFFI_OP(_CFFI_OP_POINTER, 131), // struct io_uring_sqe *
/* 29 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 30 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23), // int64_t
/* 31 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 32 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 33 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 34 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 35 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, struct msghdr *, unsigned int)
/* 37 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 38 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 39 */ _CFFI_OP(_CFFI_OP_POINTER, 134), // struct msghdr *
/* 40 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, struct msghdr const *, unsigned int)
/* 43 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 44 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 45 */ _CFFI_OP(_CFFI_OP_POINTER, 134), // struct msghdr const *
/* 46 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 48 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, struct sockaddr *, unsigned int *, int)
/* 49 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 50 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 51 */ _CFFI_OP(_CFFI_OP_POINTER, 135), // struct sockaddr *
/* 52 */ _CFFI_OP(_CFFI_OP_POINTER, 13), // unsigned int *
/* 53 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 55 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, struct sockaddr const *, unsigned int)
/* 56 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 57 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 58 */ _CFFI_OP(_CFFI_OP_POINTER, 135), // struct sockaddr const *
/* 59 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 60 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, unsigned int)
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 63 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 64 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 66 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, void *, size_t, int)
/* 67 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 68 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 69 */ _CFFI_OP(_CFFI_OP_POINTER, 159), // void *
/* 70 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/* 71 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 72 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 73 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, void *, unsigned int, unsigned long long)
/* 74 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 75 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 76 */ _CFFI_OP(_CFFI_OP_NOOP, 69),
/* 77 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 78 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 12), // unsigned long long
/* 79 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 80 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, void const *, size_t, int)
/* 81 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 82 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 83 */ _CFFI_OP(_CFFI_OP_POINTER, 159), // void const *
/* 84 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 85 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 86 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, void const *, size_t, int, struct sockaddr const *, unsigned int)
/* 88 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 89 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 90 */ _CFFI_OP(_CFFI_OP_NOOP, 83),
/* 91 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 92 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 93 */ _CFFI_OP(_CFFI_OP_NOOP, 58),
/* 94 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 95 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 96 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, int, void const *, unsigned int, unsigned long long)
/* 97 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 98 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 99 */ _CFFI_OP(_CFFI_OP_NOOP, 83),
/* 100 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 101 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 12),
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 103 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, unsigned int)
/* 104 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 105 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 107 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, unsigned long long)
/* 108 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 109 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 12),
/* 110 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 111 */ _CFFI_OP(_CFFI_OP_FUNCTION, 159), // void()(struct io_uring_sqe *, unsigned long long, int)
/* 112 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 113 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 12),
/* 114 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 116 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 117 */ _CFFI_OP(_CFFI_OP_ARRAY, 116), // char[108]
/* 118 */ (_cffi_opcode_t)(108),
/* 119 */ _CFFI_OP(_CFFI_OP_ARRAY, 116), // char[14]
/* 120 */ (_cffi_opcode_t)(14),
/* 121 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // enum $10
/* 122 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 21), // int32_t
/* 123 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 11), // long long
/* 124 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // struct __kernel_timespec
/* 125 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // struct in6_addr
/* 126 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // struct in_addr
/* 127 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // struct io_uring
/* 128 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // struct io_uring_cq
/* 129 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // struct io_uring_cqe
/* 130 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // struct io_uring_sq
/* 131 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // struct io_uring_sqe
/* 132 */ _CFFI_OP(_CFFI_OP_POINTER, 133), // struct iovec *
/* 133 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // struct iovec
/* 134 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // struct msghdr
/* 135 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // struct sockaddr
/* 136 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // struct sockaddr_in6
/* 137 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // struct sockaddr_in
/* 138 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // struct sockaddr_un
/* 139 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 20), // uint16_t
/* 140 */ _CFFI_OP(_CFFI_OP_ARRAY, 139), // uint16_t[1]
/* 141 */ (_cffi_opcode_t)(1),
/* 142 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22), // uint32_t
/* 143 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 18), // uint8_t
/* 144 */ _CFFI_OP(_CFFI_OP_ARRAY, 143), // uint8_t[0]
/* 145 */ (_cffi_opcode_t)(0),
/* 146 */ _CFFI_OP(_CFFI_OP_ARRAY, 143), // uint8_t[16]
/* 147 */ (_cffi_opcode_t)(16),
/* 148 */ _CFFI_OP(_CFFI_OP_ARRAY, 143), // uint8_t[3]
/* 149 */ (_cffi_opcode_t)(3),
/* 150 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 151 */ _CFFI_OP(_CFFI_OP_ARRAY, 150), // unsigned char[8]
/* 152 */ (_cffi_opcode_t)(8),
/* 153 */ _CFFI_OP(_CFFI_OP_ARRAY, 13), // unsigned int[2]
/* 154 */ (_cffi_opcode_t)(2),
/* 155 */ _CFFI_OP(_CFFI_OP_ARRAY, 78), // unsigned long long[1]
/* 156 */ (_cffi_opcode_t)(1),
/* 157 */ _CFFI_OP(_CFFI_OP_OPEN_ARRAY, 78), // unsigned long long[]
/* 158 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6), // unsigned short
/* 159 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_IOSQE_FIXED_FILE_BIT(unsigned long long *o)
{
  int n = (IOSQE_FIXED_FILE_BIT) <= 0;
  *o = (unsigned long long)((IOSQE_FIXED_FILE_BIT) | 0);  /* check that IOSQE_FIXED_FILE_BIT is an integer */
  return n;
}

static int _cffi_const_IOSQE_IO_DRAIN_BIT(unsigned long long *o)
{
  int n = (IOSQE_IO_DRAIN_BIT) <= 0;
  *o = (unsigned long long)((IOSQE_IO_DRAIN_BIT) | 0);  /* check that IOSQE_IO_DRAIN_BIT is an integer */
  return n;
}

static int _cffi_const_IOSQE_IO_LINK_BIT(unsigned long long *o)
{
  int n = (IOSQE_IO_LINK_BIT) <= 0;
  *o = (unsigned long long)((IOSQE_IO_LINK_BIT) | 0);  /* check that IOSQE_IO_LINK_BIT is an integer */
  return n;
}

static int _cffi_const_IOSQE_IO_HARDLINK_BIT(unsigned long long *o)
{
  int n = (IOSQE_IO_HARDLINK_BIT) <= 0;
  *o = (unsigned long long)((IOSQE_IO_HARDLINK_BIT) | 0);  /* check that IOSQE_IO_HARDLINK_BIT is an integer */
  return n;
}

static int _cffi_const_IOSQE_ASYNC_BIT(unsigned long long *o)
{
  int n = (IOSQE_ASYNC_BIT) <= 0;
  *o = (unsigned long long)((IOSQE_ASYNC_BIT) | 0);  /* check that IOSQE_ASYNC_BIT is an integer */
  return n;
}

static int _cffi_const_IOSQE_BUFFER_SELECT_BIT(unsigned long long *o)
{
  int n = (IOSQE_BUFFER_SELECT_BIT) <= 0;
  *o = (unsigned long long)((IOSQE_BUFFER_SELECT_BIT) | 0);  /* check that IOSQE_BUFFER_SELECT_BIT is an integer */
  return n;
}

static int _cffi_const_IOSQE_CQE_SKIP_SUCCESS_BIT(unsigned long long *o)
{
  int n = (IOSQE_CQE_SKIP_SUCCESS_BIT) <= 0;
  *o = (unsigned long long)((IOSQE_CQE_SKIP_SUCCESS_BIT) | 0);  /* check that IOSQE_CQE_SKIP_SUCCESS_BIT is an integer */
  return n;
}

static void _cffi_d_io_uring_cqe_seen(struct io_uring * x0, struct io_uring_cqe * x1)
{
  io_uring_cqe_seen(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_cqe_seen(PyObject *self, PyObject *args)
{
  struct io_uring * x0;
  struct io_uring_cqe * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "io_uring_cqe_seen", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct io_uring_cqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_cqe_seen(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_cqe_seen _cffi_d_io_uring_cqe_seen
#endif

static struct io_uring_sqe * _cffi_d_io_uring_get_sqe(struct io_uring * x0)
{
  return io_uring_get_sqe(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_get_sqe(PyObject *self, PyObject *arg0)
{
  struct io_uring * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct io_uring_sqe * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_get_sqe(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(28));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_get_sqe _cffi_d_io_uring_get_sqe
#endif

static int _cffi_d_io_uring_peek_cqe(struct io_uring * x0, struct io_uring_cqe * * x1)
{
  return io_uring_peek_cqe(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_peek_cqe(PyObject *self, PyObject *args)
{
  struct io_uring * x0;
  struct io_uring_cqe * * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "io_uring_peek_cqe", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(5), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct io_uring_cqe * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(5), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_peek_cqe(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_peek_cqe _cffi_d_io_uring_peek_cqe
#endif

static void _cffi_d_io_uring_prep_accept(struct io_uring_sqe * x0, int x1, struct sockaddr * x2, unsigned int * x3, int x4)
{
  io_uring_prep_accept(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_accept(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  struct sockaddr * x2;
  unsigned int * x3;
  int x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_accept", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct sockaddr *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(52), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned int *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(52), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_accept(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_accept _cffi_d_io_uring_prep_accept
#endif

static void _cffi_d_io_uring_prep_cancel64(struct io_uring_sqe * x0, unsigned long long x1, int x2)
{
  io_uring_prep_cancel64(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_cancel64(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  unsigned long long x1;
  int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_cancel64", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long long);
  if (x1 == (unsigned long long)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_cancel64(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_cancel64 _cffi_d_io_uring_prep_cancel64
#endif

static void _cffi_d_io_uring_prep_connect(struct io_uring_sqe * x0, int x1, struct sockaddr const * x2, unsigned int x3)
{
  io_uring_prep_connect(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_connect(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  struct sockaddr const * x2;
  unsigned int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_connect", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(58), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct sockaddr const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(58), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, unsigned int);
  if (x3 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_connect(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_connect _cffi_d_io_uring_prep_connect
#endif

static void _cffi_d_io_uring_prep_poll_add(struct io_uring_sqe * x0, int x1, unsigned int x2)
{
  io_uring_prep_poll_add(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_poll_add(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  unsigned int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_poll_add", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_poll_add(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_poll_add _cffi_d_io_uring_prep_poll_add
#endif

static void _cffi_d_io_uring_prep_read(struct io_uring_sqe * x0, int x1, void * x2, unsigned int x3, unsigned long long x4)
{
  io_uring_prep_read(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_read(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  void * x2;
  unsigned int x3;
  unsigned long long x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_read", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(69), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(69), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, unsigned int);
  if (x3 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned long long);
  if (x4 == (unsigned long long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_read(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_read _cffi_d_io_uring_prep_read
#endif

static void _cffi_d_io_uring_prep_recv(struct io_uring_sqe * x0, int x1, void * x2, size_t x3, int x4)
{
  io_uring_prep_recv(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_recv(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  void * x2;
  size_t x3;
  int x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_recv", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(69), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(69), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_recv(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_recv _cffi_d_io_uring_prep_recv
#endif

static void _cffi_d_io_uring_prep_recvmsg(struct io_uring_sqe * x0, int x1, struct msghdr * x2, unsigned int x3)
{
  io_uring_prep_recvmsg(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_recvmsg(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  struct msghdr * x2;
  unsigned int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_recvmsg", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(39), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct msghdr *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(39), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, unsigned int);
  if (x3 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_recvmsg(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_recvmsg _cffi_d_io_uring_prep_recvmsg
#endif

static void _cffi_d_io_uring_prep_send(struct io_uring_sqe * x0, int x1, void const * x2, size_t x3, int x4)
{
  io_uring_prep_send(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_send(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  void const * x2;
  size_t x3;
  int x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_send", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(83), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(83), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_send(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_send _cffi_d_io_uring_prep_send
#endif

static void _cffi_d_io_uring_prep_sendmsg(struct io_uring_sqe * x0, int x1, struct msghdr const * x2, unsigned int x3)
{
  io_uring_prep_sendmsg(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_sendmsg(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  struct msghdr const * x2;
  unsigned int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_sendmsg", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct msghdr const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, unsigned int);
  if (x3 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_sendmsg(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_sendmsg _cffi_d_io_uring_prep_sendmsg
#endif

static void _cffi_d_io_uring_prep_sendto(struct io_uring_sqe * x0, int x1, void const * x2, size_t x3, int x4, struct sockaddr const * x5, unsigned int x6)
{
  io_uring_prep_sendto(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_sendto(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  void const * x2;
  size_t x3;
  int x4;
  struct sockaddr const * x5;
  unsigned int x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_sendto", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(83), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(83), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(58), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (struct sockaddr const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(58), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x6 = _cffi_to_c_int(arg6, unsigned int);
  if (x6 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_sendto(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_sendto _cffi_d_io_uring_prep_sendto
#endif

static void _cffi_d_io_uring_prep_splice(struct io_uring_sqe * x0, int x1, int64_t x2, int x3, int64_t x4, unsigned int x5, unsigned int x6)
{
  io_uring_prep_splice(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_splice(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  int64_t x2;
  int x3;
  int64_t x4;
  unsigned int x5;
  unsigned int x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_splice", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, int64_t);
  if (x2 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, int64_t);
  if (x4 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned int);
  if (x5 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, unsigned int);
  if (x6 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_splice(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_splice _cffi_d_io_uring_prep_splice
#endif

static void _cffi_d_io_uring_prep_write(struct io_uring_sqe * x0, int x1, void const * x2, unsigned int x3, unsigned long long x4)
{
  io_uring_prep_write(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_prep_write(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  int x1;
  void const * x2;
  unsigned int x3;
  unsigned long long x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "io_uring_prep_write", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(83), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(83), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, unsigned int);
  if (x3 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned long long);
  if (x4 == (unsigned long long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_prep_write(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_prep_write _cffi_d_io_uring_prep_write
#endif

static void _cffi_d_io_uring_queue_exit(struct io_uring * x0)
{
  io_uring_queue_exit(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_queue_exit(PyObject *self, PyObject *arg0)
{
  struct io_uring * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_queue_exit(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_queue_exit _cffi_d_io_uring_queue_exit
#endif

static int _cffi_d_io_uring_queue_init(unsigned int x0, struct io_uring * x1, unsigned int x2)
{
  return io_uring_queue_init(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_queue_init(PyObject *self, PyObject *args)
{
  unsigned int x0;
  struct io_uring * x1;
  unsigned int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "io_uring_queue_init", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_queue_init(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_queue_init _cffi_d_io_uring_queue_init
#endif

static void _cffi_d_io_uring_sqe_set_data64(struct io_uring_sqe * x0, unsigned long long x1)
{
  io_uring_sqe_set_data64(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_sqe_set_data64(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  unsigned long long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "io_uring_sqe_set_data64", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long long);
  if (x1 == (unsigned long long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_sqe_set_data64(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_sqe_set_data64 _cffi_d_io_uring_sqe_set_data64
#endif

static void _cffi_d_io_uring_sqe_set_flags(struct io_uring_sqe * x0, unsigned int x1)
{
  io_uring_sqe_set_flags(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_sqe_set_flags(PyObject *self, PyObject *args)
{
  struct io_uring_sqe * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "io_uring_sqe_set_flags", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(28), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring_sqe *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(28), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { io_uring_sqe_set_flags(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_io_uring_sqe_set_flags _cffi_d_io_uring_sqe_set_flags
#endif

static int _cffi_d_io_uring_submit(struct io_uring * x0)
{
  return io_uring_submit(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_submit(PyObject *self, PyObject *arg0)
{
  struct io_uring * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_submit(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_submit _cffi_d_io_uring_submit
#endif

static int _cffi_d_io_uring_wait_cqe(struct io_uring * x0, struct io_uring_cqe * * x1)
{
  return io_uring_wait_cqe(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_wait_cqe(PyObject *self, PyObject *args)
{
  struct io_uring * x0;
  struct io_uring_cqe * * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "io_uring_wait_cqe", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(5), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct io_uring_cqe * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(5), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_wait_cqe(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_wait_cqe _cffi_d_io_uring_wait_cqe
#endif

static int _cffi_d_io_uring_wait_cqe_nogil(struct io_uring * x0, struct io_uring_cqe * * x1)
{
  return io_uring_wait_cqe_nogil(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_wait_cqe_nogil(PyObject *self, PyObject *args)
{
  struct io_uring * x0;
  struct io_uring_cqe * * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "io_uring_wait_cqe_nogil", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(5), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct io_uring_cqe * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(5), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_wait_cqe_nogil(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_wait_cqe_nogil _cffi_d_io_uring_wait_cqe_nogil
#endif

static int _cffi_d_io_uring_wait_cqe_timeout(struct io_uring * x0, struct io_uring_cqe * * x1, struct __kernel_timespec * x2)
{
  return io_uring_wait_cqe_timeout(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_wait_cqe_timeout(PyObject *self, PyObject *args)
{
  struct io_uring * x0;
  struct io_uring_cqe * * x1;
  struct __kernel_timespec * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "io_uring_wait_cqe_timeout", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(5), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct io_uring_cqe * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(5), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct __kernel_timespec *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(10), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_wait_cqe_timeout(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_wait_cqe_timeout _cffi_d_io_uring_wait_cqe_timeout
#endif

static int _cffi_d_io_uring_wait_cqe_timeout_nogil(struct io_uring * x0, struct io_uring_cqe * * x1, struct __kernel_timespec * x2)
{
  return io_uring_wait_cqe_timeout_nogil(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_io_uring_wait_cqe_timeout_nogil(PyObject *self, PyObject *args)
{
  struct io_uring * x0;
  struct io_uring_cqe * * x1;
  struct __kernel_timespec * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "io_uring_wait_cqe_timeout_nogil", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct io_uring *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(5), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct io_uring_cqe * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(5), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct __kernel_timespec *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(10), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = io_uring_wait_cqe_timeout_nogil(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_io_uring_wait_cqe_timeout_nogil _cffi_d_io_uring_wait_cqe_timeout_nogil
#endif

static int _cffi_const_IORING_FILE_INDEX_ALLOC(unsigned long long *o)
{
  int n = (IORING_FILE_INDEX_ALLOC) <= 0;
  *o = (unsigned long long)((IORING_FILE_INDEX_ALLOC) | 0);  /* check that IORING_FILE_INDEX_ALLOC is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_ATTACH_WQ(unsigned long long *o)
{
  int n = (IORING_SETUP_ATTACH_WQ) <= 0;
  *o = (unsigned long long)((IORING_SETUP_ATTACH_WQ) | 0);  /* check that IORING_SETUP_ATTACH_WQ is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_CLAMP(unsigned long long *o)
{
  int n = (IORING_SETUP_CLAMP) <= 0;
  *o = (unsigned long long)((IORING_SETUP_CLAMP) | 0);  /* check that IORING_SETUP_CLAMP is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_COOP_TASKRUN(unsigned long long *o)
{
  int n = (IORING_SETUP_COOP_TASKRUN) <= 0;
  *o = (unsigned long long)((IORING_SETUP_COOP_TASKRUN) | 0);  /* check that IORING_SETUP_COOP_TASKRUN is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_CQE32(unsigned long long *o)
{
  int n = (IORING_SETUP_CQE32) <= 0;
  *o = (unsigned long long)((IORING_SETUP_CQE32) | 0);  /* check that IORING_SETUP_CQE32 is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_CQSIZE(unsigned long long *o)
{
  int n = (IORING_SETUP_CQSIZE) <= 0;
  *o = (unsigned long long)((IORING_SETUP_CQSIZE) | 0);  /* check that IORING_SETUP_CQSIZE is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_DEFER_TASKRUN(unsigned long long *o)
{
  int n = (IORING_SETUP_DEFER_TASKRUN) <= 0;
  *o = (unsigned long long)((IORING_SETUP_DEFER_TASKRUN) | 0);  /* check that IORING_SETUP_DEFER_TASKRUN is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_IOPOLL(unsigned long long *o)
{
  int n = (IORING_SETUP_IOPOLL) <= 0;
  *o = (unsigned long long)((IORING_SETUP_IOPOLL) | 0);  /* check that IORING_SETUP_IOPOLL is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_NO_MMAP(unsigned long long *o)
{
  int n = (IORING_SETUP_NO_MMAP) <= 0;
  *o = (unsigned long long)((IORING_SETUP_NO_MMAP) | 0);  /* check that IORING_SETUP_NO_MMAP is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_REGISTERED_FD_ONLY(unsigned long long *o)
{
  int n = (IORING_SETUP_REGISTERED_FD_ONLY) <= 0;
  *o = (unsigned long long)((IORING_SETUP_REGISTERED_FD_ONLY) | 0);  /* check that IORING_SETUP_REGISTERED_FD_ONLY is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_R_DISABLED(unsigned long long *o)
{
  int n = (IORING_SETUP_R_DISABLED) <= 0;
  *o = (unsigned long long)((IORING_SETUP_R_DISABLED) | 0);  /* check that IORING_SETUP_R_DISABLED is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_SINGLE_ISSUER(unsigned long long *o)
{
  int n = (IORING_SETUP_SINGLE_ISSUER) <= 0;
  *o = (unsigned long long)((IORING_SETUP_SINGLE_ISSUER) | 0);  /* check that IORING_SETUP_SINGLE_ISSUER is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_SQE128(unsigned long long *o)
{
  int n = (IORING_SETUP_SQE128) <= 0;
  *o = (unsigned long long)((IORING_SETUP_SQE128) | 0);  /* check that IORING_SETUP_SQE128 is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_SQPOLL(unsigned long long *o)
{
  int n = (IORING_SETUP_SQPOLL) <= 0;
  *o = (unsigned long long)((IORING_SETUP_SQPOLL) | 0);  /* check that IORING_SETUP_SQPOLL is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_SQ_AFF(unsigned long long *o)
{
  int n = (IORING_SETUP_SQ_AFF) <= 0;
  *o = (unsigned long long)((IORING_SETUP_SQ_AFF) | 0);  /* check that IORING_SETUP_SQ_AFF is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_SUBMIT_ALL(unsigned long long *o)
{
  int n = (IORING_SETUP_SUBMIT_ALL) <= 0;
  *o = (unsigned long long)((IORING_SETUP_SUBMIT_ALL) | 0);  /* check that IORING_SETUP_SUBMIT_ALL is an integer */
  return n;
}

static int _cffi_const_IORING_SETUP_TASKRUN_FLAG(unsigned long long *o)
{
  int n = (IORING_SETUP_TASKRUN_FLAG) <= 0;
  *o = (unsigned long long)((IORING_SETUP_TASKRUN_FLAG) | 0);  /* check that IORING_SETUP_TASKRUN_FLAG is an integer */
  return n;
}

static int _cffi_const_IOSQE_ASYNC(unsigned long long *o)
{
  int n = (IOSQE_ASYNC) <= 0;
  *o = (unsigned long long)((IOSQE_ASYNC) | 0);  /* check that IOSQE_ASYNC is an integer */
  return n;
}

static int _cffi_const_IOSQE_BUFFER_SELECT(unsigned long long *o)
{
  int n = (IOSQE_BUFFER_SELECT) <= 0;
  *o = (unsigned long long)((IOSQE_BUFFER_SELECT) | 0);  /* check that IOSQE_BUFFER_SELECT is an integer */
  return n;
}

static int _cffi_const_IOSQE_CQE_SKIP_SUCCESS(unsigned long long *o)
{
  int n = (IOSQE_CQE_SKIP_SUCCESS) <= 0;
  *o = (unsigned long long)((IOSQE_CQE_SKIP_SUCCESS) | 0);  /* check that IOSQE_CQE_SKIP_SUCCESS is an integer */
  return n;
}

static int _cffi_const_IOSQE_FIXED_FILE(unsigned long long *o)
{
  int n = (IOSQE_FIXED_FILE) <= 0;
  *o = (unsigned long long)((IOSQE_FIXED_FILE) | 0);  /* check that IOSQE_FIXED_FILE is an integer */
  return n;
}

static int _cffi_const_IOSQE_IO_DRAIN(unsigned long long *o)
{
  int n = (IOSQE_IO_DRAIN) <= 0;
  *o = (unsigned long long)((IOSQE_IO_DRAIN) | 0);  /* check that IOSQE_IO_DRAIN is an integer */
  return n;
}

static int _cffi_const_IOSQE_IO_HARDLINK(unsigned long long *o)
{
  int n = (IOSQE_IO_HARDLINK) <= 0;
  *o = (unsigned long long)((IOSQE_IO_HARDLINK) | 0);  /* check that IOSQE_IO_HARDLINK is an integer */
  return n;
}

static int _cffi_const_IOSQE_IO_LINK(unsigned long long *o)
{
  int n = (IOSQE_IO_LINK) <= 0;
  *o = (unsigned long long)((IOSQE_IO_LINK) | 0);  /* check that IOSQE_IO_LINK is an integer */
  return n;
}

static int _cffi_const_POLLERR(unsigned long long *o)
{
  int n = (POLLERR) <= 0;
  *o = (unsigned long long)((POLLERR) | 0);  /* check that POLLERR is an integer */
  return n;
}

static int _cffi_const_POLLHUP(unsigned long long *o)
{
  int n = (POLLHUP) <= 0;
  *o = (unsigned long long)((POLLHUP) | 0);  /* check that POLLHUP is an integer */
  return n;
}

static int _cffi_const_POLLIN(unsigned long long *o)
{
  int n = (POLLIN) <= 0;
  *o = (unsigned long long)((POLLIN) | 0);  /* check that POLLIN is an integer */
  return n;
}

static int _cffi_const_POLLNVAL(unsigned long long *o)
{
  int n = (POLLNVAL) <= 0;
  *o = (unsigned long long)((POLLNVAL) | 0);  /* check that POLLNVAL is an integer */
  return n;
}

static int _cffi_const_POLLOUT(unsigned long long *o)
{
  int n = (POLLOUT) <= 0;
  *o = (unsigned long long)((POLLOUT) | 0);  /* check that POLLOUT is an integer */
  return n;
}

static int _cffi_const_POLLPRI(unsigned long long *o)
{
  int n = (POLLPRI) <= 0;
  *o = (unsigned long long)((POLLPRI) | 0);  /* check that POLLPRI is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct___kernel_timespec(struct __kernel_timespec *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->tv_sec) | 0);  /* check that 'struct __kernel_timespec.tv_sec' is an integer */
  (void)((p->tv_nsec) | 0);  /* check that 'struct __kernel_timespec.tv_nsec' is an integer */
}
struct _cffi_align_struct___kernel_timespec { char x; struct __kernel_timespec y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_in6_addr(struct in6_addr *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { uint8_t(*tmp)[16] = &p->s6_addr; (void)tmp; }
}
struct _cffi_align_struct_in6_addr { char x; struct in6_addr y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_in_addr(struct in_addr *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->s_addr) | 0);  /* check that 'struct in_addr.s_addr' is an integer */
}
struct _cffi_align_struct_in_addr { char x; struct in_addr y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_io_uring(struct io_uring *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct io_uring_sq *tmp = &p->sq; (void)tmp; }
  { struct io_uring_cq *tmp = &p->cq; (void)tmp; }
  (void)((p->flags) | 0);  /* check that 'struct io_uring.flags' is an integer */
  (void)((p->ring_fd) | 0);  /* check that 'struct io_uring.ring_fd' is an integer */
  (void)((p->features) | 0);  /* check that 'struct io_uring.features' is an integer */
  (void)((p->enter_ring_fd) | 0);  /* check that 'struct io_uring.enter_ring_fd' is an integer */
  (void)((p->int_flags) | 0);  /* check that 'struct io_uring.int_flags' is an integer */
  { uint8_t(*tmp)[3] = &p->pad; (void)tmp; }
  (void)((p->pad2) | 0);  /* check that 'struct io_uring.pad2' is an integer */
}
struct _cffi_align_struct_io_uring { char x; struct io_uring y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_io_uring_cq(struct io_uring_cq *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { unsigned int * *tmp = &p->khead; (void)tmp; }
  { unsigned int * *tmp = &p->ktail; (void)tmp; }
  { unsigned int * *tmp = &p->kring_mask; (void)tmp; }
  { unsigned int * *tmp = &p->kring_entries; (void)tmp; }
  { unsigned int * *tmp = &p->kflags; (void)tmp; }
  { unsigned int * *tmp = &p->koverflow; (void)tmp; }
  { struct io_uring_cqe * *tmp = &p->cqes; (void)tmp; }
  (void)((p->ring_sz) | 0);  /* check that 'struct io_uring_cq.ring_sz' is an integer */
  { void * *tmp = &p->ring_ptr; (void)tmp; }
  (void)((p->ring_mask) | 0);  /* check that 'struct io_uring_cq.ring_mask' is an integer */
  (void)((p->ring_entries) | 0);  /* check that 'struct io_uring_cq.ring_entries' is an integer */
  { unsigned int(*tmp)[2] = &p->pad; (void)tmp; }
}
struct _cffi_align_struct_io_uring_cq { char x; struct io_uring_cq y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_io_uring_cqe(struct io_uring_cqe *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->user_data) | 0);  /* check that 'struct io_uring_cqe.user_data' is an integer */
  (void)((p->res) | 0);  /* check that 'struct io_uring_cqe.res' is an integer */
  (void)((p->flags) | 0);  /* check that 'struct io_uring_cqe.flags' is an integer */
  { unsigned long long *tmp = &p->big_cqe[0]; (void)tmp; }
}
struct _cffi_align_struct_io_uring_cqe { char x; struct io_uring_cqe y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_io_uring_sq(struct io_uring_sq *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { unsigned int * *tmp = &p->khead; (void)tmp; }
  { unsigned int * *tmp = &p->ktail; (void)tmp; }
  { unsigned int * *tmp = &p->kring_mask; (void)tmp; }
  { unsigned int * *tmp = &p->kring_entries; (void)tmp; }
  { unsigned int * *tmp = &p->kflags; (void)tmp; }
  { unsigned int * *tmp = &p->kdropped; (void)tmp; }
  { unsigned int * *tmp = &p->array; (void)tmp; }
  { struct io_uring_sqe * *tmp = &p->sqes; (void)tmp; }
  (void)((p->sqe_head) | 0);  /* check that 'struct io_uring_sq.sqe_head' is an integer */
  (void)((p->sqe_tail) | 0);  /* check that 'struct io_uring_sq.sqe_tail' is an integer */
  (void)((p->ring_sz) | 0);  /* check that 'struct io_uring_sq.ring_sz' is an integer */
  { void * *tmp = &p->ring_ptr; (void)tmp; }
  (void)((p->ring_mask) | 0);  /* check that 'struct io_uring_sq.ring_mask' is an integer */
  (void)((p->ring_entries) | 0);  /* check that 'struct io_uring_sq.ring_entries' is an integer */
  { unsigned int(*tmp)[2] = &p->pad; (void)tmp; }
}
struct _cffi_align_struct_io_uring_sq { char x; struct io_uring_sq y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_io_uring_sqe(struct io_uring_sqe *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->opcode) | 0);  /* check that 'struct io_uring_sqe.opcode' is an integer */
  (void)((p->flags) | 0);  /* check that 'struct io_uring_sqe.flags' is an integer */
  (void)((p->ioprio) | 0);  /* check that 'struct io_uring_sqe.ioprio' is an integer */
  (void)((p->fd) | 0);  /* check that 'struct io_uring_sqe.fd' is an integer */
  (void)((p->off) | 0);  /* check that 'struct io_uring_sqe.off' is an integer */
  (void)((p->addr2) | 0);  /* check that 'struct io_uring_sqe.addr2' is an integer */
  (void)((p->cmd_op) | 0);  /* check that 'struct io_uring_sqe.cmd_op' is an integer */
  (void)((p->__pad1) | 0);  /* check that 'struct io_uring_sqe.__pad1' is an integer */
  (void)((p->addr) | 0);  /* check that 'struct io_uring_sqe.addr' is an integer */
  (void)((p->splice_off_in) | 0);  /* check that 'struct io_uring_sqe.splice_off_in' is an integer */
  (void)((p->len) | 0);  /* check that 'struct io_uring_sqe.len' is an integer */
  (void)((p->rw_flags) | 0);  /* check that 'struct io_uring_sqe.rw_flags' is an integer */
  (void)((p->fsync_flags) | 0);  /* check that 'struct io_uring_sqe.fsync_flags' is an integer */
  (void)((p->poll_events) | 0);  /* check that 'struct io_uring_sqe.poll_events' is an integer */
  (void)((p->poll32_events) | 0);  /* check that 'struct io_uring_sqe.poll32_events' is an integer */
  (void)((p->sync_range_flags) | 0);  /* check that 'struct io_uring_sqe.sync_range_flags' is an integer */
  (void)((p->msg_flags) | 0);  /* check that 'struct io_uring_sqe.msg_flags' is an integer */
  (void)((p->timeout_flags) | 0);  /* check that 'struct io_uring_sqe.timeout_flags' is an integer */
  (void)((p->accept_flags) | 0);  /* check that 'struct io_uring_sqe.accept_flags' is an integer */
  (void)((p->cancel_flags) | 0);  /* check that 'struct io_uring_sqe.cancel_flags' is an integer */
  (void)((p->open_flags) | 0);  /* check that 'struct io_uring_sqe.open_flags' is an integer */
  (void)((p->statx_flags) | 0);  /* check that 'struct io_uring_sqe.statx_flags' is an integer */
  (void)((p->fadvise_advice) | 0);  /* check that 'struct io_uring_sqe.fadvise_advice' is an integer */
  (void)((p->splice_flags) | 0);  /* check that 'struct io_uring_sqe.splice_flags' is an integer */
  (void)((p->rename_flags) | 0);  /* check that 'struct io_uring_sqe.rename_flags' is an integer */
  (void)((p->unlink_flags) | 0);  /* check that 'struct io_uring_sqe.unlink_flags' is an integer */
  (void)((p->hardlink_flags) | 0);  /* check that 'struct io_uring_sqe.hardlink_flags' is an integer */
  (void)((p->xattr_flags) | 0);  /* check that 'struct io_uring_sqe.xattr_flags' is an integer */
  (void)((p->msg_ring_flags) | 0);  /* check that 'struct io_uring_sqe.msg_ring_flags' is an integer */
  (void)((p->uring_cmd_flags) | 0);  /* check that 'struct io_uring_sqe.uring_cmd_flags' is an integer */
  (void)((p->user_data) | 0);  /* check that 'struct io_uring_sqe.user_data' is an integer */
  (void)((p->buf_index) | 0);  /* check that 'struct io_uring_sqe.buf_index' is an integer */
  (void)((p->buf_group) | 0);  /* check that 'struct io_uring_sqe.buf_group' is an integer */
  (void)((p->personality) | 0);  /* check that 'struct io_uring_sqe.personality' is an integer */
  (void)((p->splice_fd_in) | 0);  /* check that 'struct io_uring_sqe.splice_fd_in' is an integer */
  (void)((p->file_index) | 0);  /* check that 'struct io_uring_sqe.file_index' is an integer */
  (void)((p->addr_len) | 0);  /* check that 'struct io_uring_sqe.addr_len' is an integer */
  { uint16_t(*tmp)[1] = &p->__pad3; (void)tmp; }
  (void)((p->addr3) | 0);  /* check that 'struct io_uring_sqe.addr3' is an integer */
  { unsigned long long(*tmp)[1] = &p->__pad2; (void)tmp; }
  { uint8_t(*tmp)[0] = &p->cmd; (void)tmp; }
}
struct _cffi_align_struct_io_uring_sqe { char x; struct io_uring_sqe y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_iovec(struct iovec *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void * *tmp = &p->iov_base; (void)tmp; }
  (void)((p->iov_len) | 0);  /* check that 'struct iovec.iov_len' is an integer */
}
struct _cffi_align_struct_iovec { char x; struct iovec y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_msghdr(struct msghdr *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void * *tmp = &p->msg_name; (void)tmp; }
  (void)((p->msg_namelen) | 0);  /* check that 'struct msghdr.msg_namelen' is an integer */
  { struct iovec * *tmp = &p->msg_iov; (void)tmp; }
  (void)((p->msg_iovlen) | 0);  /* check that 'struct msghdr.msg_iovlen' is an integer */
  { void * *tmp = &p->msg_control; (void)tmp; }
  (void)((p->msg_controllen) | 0);  /* check that 'struct msghdr.msg_controllen' is an integer */
  (void)((p->msg_flags) | 0);  /* check that 'struct msghdr.msg_flags' is an integer */
}
struct _cffi_align_struct_msghdr { char x; struct msghdr y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_sockaddr(struct sockaddr *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->sa_family) | 0);  /* check that 'struct sockaddr.sa_family' is an integer */
  { char(*tmp)[14] = &p->sa_data; (void)tmp; }
}
struct _cffi_align_struct_sockaddr { char x; struct sockaddr y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_sockaddr_in(struct sockaddr_in *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->sin_family) | 0);  /* check that 'struct sockaddr_in.sin_family' is an integer */
  (void)((p->sin_port) | 0);  /* check that 'struct sockaddr_in.sin_port' is an integer */
  { struct in_addr *tmp = &p->sin_addr; (void)tmp; }
  { unsigned char(*tmp)[8] = &p->sin_zero; (void)tmp; }
}
struct _cffi_align_struct_sockaddr_in { char x; struct sockaddr_in y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_sockaddr_in6(struct sockaddr_in6 *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->sin6_family) | 0);  /* check that 'struct sockaddr_in6.sin6_family' is an integer */
  (void)((p->sin6_port) | 0);  /* check that 'struct sockaddr_in6.sin6_port' is an integer */
  (void)((p->sin6_flowinfo) | 0);  /* check that 'struct sockaddr_in6.sin6_flowinfo' is an integer */
  { struct in6_addr *tmp = &p->sin6_addr; (void)tmp; }
  (void)((p->sin6_scope_id) | 0);  /* check that 'struct sockaddr_in6.sin6_scope_id' is an integer */
}
struct _cffi_align_struct_sockaddr_in6 { char x; struct sockaddr_in6 y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_sockaddr_un(struct sockaddr_un *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->sun_family) | 0);  /* check that 'struct sockaddr_un.sun_family' is an integer */
  { char(*tmp)[108] = &p->sun_path; (void)tmp; }
}
struct _cffi_align_struct_sockaddr_un { char x; struct sockaddr_un y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "IORING_FILE_INDEX_ALLOC", (void *)_cffi_const_IORING_FILE_INDEX_ALLOC, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_ATTACH_WQ", (void *)_cffi_const_IORING_SETUP_ATTACH_WQ, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_CLAMP", (void *)_cffi_const_IORING_SETUP_CLAMP, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_COOP_TASKRUN", (void *)_cffi_const_IORING_SETUP_COOP_TASKRUN, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_CQE32", (void *)_cffi_const_IORING_SETUP_CQE32, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_CQSIZE", (void *)_cffi_const_IORING_SETUP_CQSIZE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_DEFER_TASKRUN", (void *)_cffi_const_IORING_SETUP_DEFER_TASKRUN, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_IOPOLL", (void *)_cffi_const_IORING_SETUP_IOPOLL, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_NO_MMAP", (void *)_cffi_const_IORING_SETUP_NO_MMAP, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_REGISTERED_FD_ONLY", (void *)_cffi_const_IORING_SETUP_REGISTERED_FD_ONLY, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_R_DISABLED", (void *)_cffi_const_IORING_SETUP_R_DISABLED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_SINGLE_ISSUER", (void *)_cffi_const_IORING_SETUP_SINGLE_ISSUER, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_SQE128", (void *)_cffi_const_IORING_SETUP_SQE128, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_SQPOLL", (void *)_cffi_const_IORING_SETUP_SQPOLL, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_SQ_AFF", (void *)_cffi_const_IORING_SETUP_SQ_AFF, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_SUBMIT_ALL", (void *)_cffi_const_IORING_SETUP_SUBMIT_ALL, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IORING_SETUP_TASKRUN_FLAG", (void *)_cffi_const_IORING_SETUP_TASKRUN_FLAG, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_ASYNC", (void *)_cffi_const_IOSQE_ASYNC, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_ASYNC_BIT", (void *)_cffi_const_IOSQE_ASYNC_BIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "IOSQE_BUFFER_SELECT", (void *)_cffi_const_IOSQE_BUFFER_SELECT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_BUFFER_SELECT_BIT", (void *)_cffi_const_IOSQE_BUFFER_SELECT_BIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "IOSQE_CQE_SKIP_SUCCESS", (void *)_cffi_const_IOSQE_CQE_SKIP_SUCCESS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_CQE_SKIP_SUCCESS_BIT", (void *)_cffi_const_IOSQE_CQE_SKIP_SUCCESS_BIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "IOSQE_FIXED_FILE", (void *)_cffi_const_IOSQE_FIXED_FILE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_FIXED_FILE_BIT", (void *)_cffi_const_IOSQE_FIXED_FILE_BIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "IOSQE_IO_DRAIN", (void *)_cffi_const_IOSQE_IO_DRAIN, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_IO_DRAIN_BIT", (void *)_cffi_const_IOSQE_IO_DRAIN_BIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "IOSQE_IO_HARDLINK", (void *)_cffi_const_IOSQE_IO_HARDLINK, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_IO_HARDLINK_BIT", (void *)_cffi_const_IOSQE_IO_HARDLINK_BIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "IOSQE_IO_LINK", (void *)_cffi_const_IOSQE_IO_LINK, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "IOSQE_IO_LINK_BIT", (void *)_cffi_const_IOSQE_IO_LINK_BIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "POLLERR", (void *)_cffi_const_POLLERR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "POLLHUP", (void *)_cffi_const_POLLHUP, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "POLLIN", (void *)_cffi_const_POLLIN, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "POLLNVAL", (void *)_cffi_const_POLLNVAL, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "POLLOUT", (void *)_cffi_const_POLLOUT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "POLLPRI", (void *)_cffi_const_POLLPRI, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "io_uring_cqe_seen", (void *)_cffi_f_io_uring_cqe_seen, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 23), (void *)_cffi_d_io_uring_cqe_seen },
  { "io_uring_get_sqe", (void *)_cffi_f_io_uring_get_sqe, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 17), (void *)_cffi_d_io_uring_get_sqe },
  { "io_uring_peek_cqe", (void *)_cffi_f_io_uring_peek_cqe, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 3), (void *)_cffi_d_io_uring_peek_cqe },
  { "io_uring_prep_accept", (void *)_cffi_f_io_uring_prep_accept, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 48), (void *)_cffi_d_io_uring_prep_accept },
  { "io_uring_prep_cancel64", (void *)_cffi_f_io_uring_prep_cancel64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 111), (void *)_cffi_d_io_uring_prep_cancel64 },
  { "io_uring_prep_connect", (void *)_cffi_f_io_uring_prep_connect, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 55), (void *)_cffi_d_io_uring_prep_connect },
  { "io_uring_prep_poll_add", (void *)_cffi_f_io_uring_prep_poll_add, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 61), (void *)_cffi_d_io_uring_prep_poll_add },
  { "io_uring_prep_read", (void *)_cffi_f_io_uring_prep_read, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 73), (void *)_cffi_d_io_uring_prep_read },
  { "io_uring_prep_recv", (void *)_cffi_f_io_uring_prep_recv, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 66), (void *)_cffi_d_io_uring_prep_recv },
  { "io_uring_prep_recvmsg", (void *)_cffi_f_io_uring_prep_recvmsg, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 36), (void *)_cffi_d_io_uring_prep_recvmsg },
  { "io_uring_prep_send", (void *)_cffi_f_io_uring_prep_send, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 80), (void *)_cffi_d_io_uring_prep_send },
  { "io_uring_prep_sendmsg", (void *)_cffi_f_io_uring_prep_sendmsg, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 42), (void *)_cffi_d_io_uring_prep_sendmsg },
  { "io_uring_prep_sendto", (void *)_cffi_f_io_uring_prep_sendto, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 87), (void *)_cffi_d_io_uring_prep_sendto },
  { "io_uring_prep_splice", (void *)_cffi_f_io_uring_prep_splice, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 27), (void *)_cffi_d_io_uring_prep_splice },
  { "io_uring_prep_write", (void *)_cffi_f_io_uring_prep_write, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 96), (void *)_cffi_d_io_uring_prep_write },
  { "io_uring_queue_exit", (void *)_cffi_f_io_uring_queue_exit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 20), (void *)_cffi_d_io_uring_queue_exit },
  { "io_uring_queue_init", (void *)_cffi_f_io_uring_queue_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 12), (void *)_cffi_d_io_uring_queue_init },
  { "io_uring_sqe_set_data64", (void *)_cffi_f_io_uring_sqe_set_data64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 107), (void *)_cffi_d_io_uring_sqe_set_data64 },
  { "io_uring_sqe_set_flags", (void *)_cffi_f_io_uring_sqe_set_flags, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 103), (void *)_cffi_d_io_uring_sqe_set_flags },
  { "io_uring_submit", (void *)_cffi_f_io_uring_submit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_io_uring_submit },
  { "io_uring_wait_cqe", (void *)_cffi_f_io_uring_wait_cqe, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 3), (void *)_cffi_d_io_uring_wait_cqe },
  { "io_uring_wait_cqe_nogil", (void *)_cffi_f_io_uring_wait_cqe_nogil, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 3), (void *)_cffi_d_io_uring_wait_cqe_nogil },
  { "io_uring_wait_cqe_timeout", (void *)_cffi_f_io_uring_wait_cqe_timeout, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 7), (void *)_cffi_d_io_uring_wait_cqe_timeout },
  { "io_uring_wait_cqe_timeout_nogil", (void *)_cffi_f_io_uring_wait_cqe_timeout_nogil, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 7), (void *)_cffi_d_io_uring_wait_cqe_timeout_nogil },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "tv_sec", offsetof(struct __kernel_timespec, tv_sec),
              sizeof(((struct __kernel_timespec *)0)->tv_sec),
              _CFFI_OP(_CFFI_OP_NOOP, 30) },
  { "tv_nsec", offsetof(struct __kernel_timespec, tv_nsec),
               sizeof(((struct __kernel_timespec *)0)->tv_nsec),
               _CFFI_OP(_CFFI_OP_NOOP, 123) },
  { "s6_addr", offsetof(struct in6_addr, s6_addr),
               sizeof(((struct in6_addr *)0)->s6_addr),
               _CFFI_OP(_CFFI_OP_NOOP, 146) },
  { "s_addr", offsetof(struct in_addr, s_addr),
              sizeof(((struct in_addr *)0)->s_addr),
              _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "sq", offsetof(struct io_uring, sq),
          sizeof(((struct io_uring *)0)->sq),
          _CFFI_OP(_CFFI_OP_NOOP, 130) },
  { "cq", offsetof(struct io_uring, cq),
          sizeof(((struct io_uring *)0)->cq),
          _CFFI_OP(_CFFI_OP_NOOP, 128) },
  { "flags", offsetof(struct io_uring, flags),
             sizeof(((struct io_uring *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "ring_fd", offsetof(struct io_uring, ring_fd),
               sizeof(((struct io_uring *)0)->ring_fd),
               _CFFI_OP(_CFFI_OP_NOOP, 29) },
  { "features", offsetof(struct io_uring, features),
                sizeof(((struct io_uring *)0)->features),
                _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "enter_ring_fd", offsetof(struct io_uring, enter_ring_fd),
                     sizeof(((struct io_uring *)0)->enter_ring_fd),
                     _CFFI_OP(_CFFI_OP_NOOP, 29) },
  { "int_flags", offsetof(struct io_uring, int_flags),
                 sizeof(((struct io_uring *)0)->int_flags),
                 _CFFI_OP(_CFFI_OP_NOOP, 143) },
  { "pad", offsetof(struct io_uring, pad),
           sizeof(((struct io_uring *)0)->pad),
           _CFFI_OP(_CFFI_OP_NOOP, 148) },
  { "pad2", offsetof(struct io_uring, pad2),
            sizeof(((struct io_uring *)0)->pad2),
            _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "khead", offsetof(struct io_uring_cq, khead),
             sizeof(((struct io_uring_cq *)0)->khead),
             _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "ktail", offsetof(struct io_uring_cq, ktail),
             sizeof(((struct io_uring_cq *)0)->ktail),
             _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "kring_mask", offsetof(struct io_uring_cq, kring_mask),
                  sizeof(((struct io_uring_cq *)0)->kring_mask),
                  _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "kring_entries", offsetof(struct io_uring_cq, kring_entries),
                     sizeof(((struct io_uring_cq *)0)->kring_entries),
                     _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "kflags", offsetof(struct io_uring_cq, kflags),
              sizeof(((struct io_uring_cq *)0)->kflags),
              _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "koverflow", offsetof(struct io_uring_cq, koverflow),
                 sizeof(((struct io_uring_cq *)0)->koverflow),
                 _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "cqes", offsetof(struct io_uring_cq, cqes),
            sizeof(((struct io_uring_cq *)0)->cqes),
            _CFFI_OP(_CFFI_OP_NOOP, 25) },
  { "ring_sz", offsetof(struct io_uring_cq, ring_sz),
               sizeof(((struct io_uring_cq *)0)->ring_sz),
               _CFFI_OP(_CFFI_OP_NOOP, 70) },
  { "ring_ptr", offsetof(struct io_uring_cq, ring_ptr),
                sizeof(((struct io_uring_cq *)0)->ring_ptr),
                _CFFI_OP(_CFFI_OP_NOOP, 69) },
  { "ring_mask", offsetof(struct io_uring_cq, ring_mask),
                 sizeof(((struct io_uring_cq *)0)->ring_mask),
                 _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "ring_entries", offsetof(struct io_uring_cq, ring_entries),
                    sizeof(((struct io_uring_cq *)0)->ring_entries),
                    _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "pad", offsetof(struct io_uring_cq, pad),
           sizeof(((struct io_uring_cq *)0)->pad),
           _CFFI_OP(_CFFI_OP_NOOP, 153) },
  { "user_data", offsetof(struct io_uring_cqe, user_data),
                 sizeof(((struct io_uring_cqe *)0)->user_data),
                 _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "res", offsetof(struct io_uring_cqe, res),
           sizeof(((struct io_uring_cqe *)0)->res),
           _CFFI_OP(_CFFI_OP_NOOP, 122) },
  { "flags", offsetof(struct io_uring_cqe, flags),
             sizeof(((struct io_uring_cqe *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "big_cqe", offsetof(struct io_uring_cqe, big_cqe),
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 157) },
  { "khead", offsetof(struct io_uring_sq, khead),
             sizeof(((struct io_uring_sq *)0)->khead),
             _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "ktail", offsetof(struct io_uring_sq, ktail),
             sizeof(((struct io_uring_sq *)0)->ktail),
             _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "kring_mask", offsetof(struct io_uring_sq, kring_mask),
                  sizeof(((struct io_uring_sq *)0)->kring_mask),
                  _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "kring_entries", offsetof(struct io_uring_sq, kring_entries),
                     sizeof(((struct io_uring_sq *)0)->kring_entries),
                     _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "kflags", offsetof(struct io_uring_sq, kflags),
              sizeof(((struct io_uring_sq *)0)->kflags),
              _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "kdropped", offsetof(struct io_uring_sq, kdropped),
                sizeof(((struct io_uring_sq *)0)->kdropped),
                _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "array", offsetof(struct io_uring_sq, array),
             sizeof(((struct io_uring_sq *)0)->array),
             _CFFI_OP(_CFFI_OP_NOOP, 52) },
  { "sqes", offsetof(struct io_uring_sq, sqes),
            sizeof(((struct io_uring_sq *)0)->sqes),
            _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "sqe_head", offsetof(struct io_uring_sq, sqe_head),
                sizeof(((struct io_uring_sq *)0)->sqe_head),
                _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "sqe_tail", offsetof(struct io_uring_sq, sqe_tail),
                sizeof(((struct io_uring_sq *)0)->sqe_tail),
                _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "ring_sz", offsetof(struct io_uring_sq, ring_sz),
               sizeof(((struct io_uring_sq *)0)->ring_sz),
               _CFFI_OP(_CFFI_OP_NOOP, 70) },
  { "ring_ptr", offsetof(struct io_uring_sq, ring_ptr),
                sizeof(((struct io_uring_sq *)0)->ring_ptr),
                _CFFI_OP(_CFFI_OP_NOOP, 69) },
  { "ring_mask", offsetof(struct io_uring_sq, ring_mask),
                 sizeof(((struct io_uring_sq *)0)->ring_mask),
                 _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "ring_entries", offsetof(struct io_uring_sq, ring_entries),
                    sizeof(((struct io_uring_sq *)0)->ring_entries),
                    _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "pad", offsetof(struct io_uring_sq, pad),
           sizeof(((struct io_uring_sq *)0)->pad),
           _CFFI_OP(_CFFI_OP_NOOP, 153) },
  { "opcode", offsetof(struct io_uring_sqe, opcode),
              sizeof(((struct io_uring_sqe *)0)->opcode),
              _CFFI_OP(_CFFI_OP_NOOP, 143) },
  { "flags", offsetof(struct io_uring_sqe, flags),
             sizeof(((struct io_uring_sqe *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 143) },
  { "ioprio", offsetof(struct io_uring_sqe, ioprio),
              sizeof(((struct io_uring_sqe *)0)->ioprio),
              _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "fd", offsetof(struct io_uring_sqe, fd),
          sizeof(((struct io_uring_sqe *)0)->fd),
          _CFFI_OP(_CFFI_OP_NOOP, 122) },
  { "off", offsetof(struct io_uring_sqe, off),
           sizeof(((struct io_uring_sqe *)0)->off),
           _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "addr2", offsetof(struct io_uring_sqe, addr2),
             sizeof(((struct io_uring_sqe *)0)->addr2),
             _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "cmd_op", offsetof(struct io_uring_sqe, cmd_op),
              sizeof(((struct io_uring_sqe *)0)->cmd_op),
              _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "__pad1", offsetof(struct io_uring_sqe, __pad1),
              sizeof(((struct io_uring_sqe *)0)->__pad1),
              _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "addr", offsetof(struct io_uring_sqe, addr),
            sizeof(((struct io_uring_sqe *)0)->addr),
            _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "splice_off_in", offsetof(struct io_uring_sqe, splice_off_in),
                     sizeof(((struct io_uring_sqe *)0)->splice_off_in),
                     _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "len", offsetof(struct io_uring_sqe, len),
           sizeof(((struct io_uring_sqe *)0)->len),
           _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "rw_flags", offsetof(struct io_uring_sqe, rw_flags),
                sizeof(((struct io_uring_sqe *)0)->rw_flags),
                _CFFI_OP(_CFFI_OP_NOOP, 29) },
  { "fsync_flags", offsetof(struct io_uring_sqe, fsync_flags),
                   sizeof(((struct io_uring_sqe *)0)->fsync_flags),
                   _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "poll_events", offsetof(struct io_uring_sqe, poll_events),
                   sizeof(((struct io_uring_sqe *)0)->poll_events),
                   _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "poll32_events", offsetof(struct io_uring_sqe, poll32_events),
                     sizeof(((struct io_uring_sqe *)0)->poll32_events),
                     _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "sync_range_flags", offsetof(struct io_uring_sqe, sync_range_flags),
                        sizeof(((struct io_uring_sqe *)0)->sync_range_flags),
                        _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "msg_flags", offsetof(struct io_uring_sqe, msg_flags),
                 sizeof(((struct io_uring_sqe *)0)->msg_flags),
                 _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "timeout_flags", offsetof(struct io_uring_sqe, timeout_flags),
                     sizeof(((struct io_uring_sqe *)0)->timeout_flags),
                     _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "accept_flags", offsetof(struct io_uring_sqe, accept_flags),
                    sizeof(((struct io_uring_sqe *)0)->accept_flags),
                    _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "cancel_flags", offsetof(struct io_uring_sqe, cancel_flags),
                    sizeof(((struct io_uring_sqe *)0)->cancel_flags),
                    _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "open_flags", offsetof(struct io_uring_sqe, open_flags),
                  sizeof(((struct io_uring_sqe *)0)->open_flags),
                  _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "statx_flags", offsetof(struct io_uring_sqe, statx_flags),
                   sizeof(((struct io_uring_sqe *)0)->statx_flags),
                   _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "fadvise_advice", offsetof(struct io_uring_sqe, fadvise_advice),
                      sizeof(((struct io_uring_sqe *)0)->fadvise_advice),
                      _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "splice_flags", offsetof(struct io_uring_sqe, splice_flags),
                    sizeof(((struct io_uring_sqe *)0)->splice_flags),
                    _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "rename_flags", offsetof(struct io_uring_sqe, rename_flags),
                    sizeof(((struct io_uring_sqe *)0)->rename_flags),
                    _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "unlink_flags", offsetof(struct io_uring_sqe, unlink_flags),
                    sizeof(((struct io_uring_sqe *)0)->unlink_flags),
                    _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "hardlink_flags", offsetof(struct io_uring_sqe, hardlink_flags),
                      sizeof(((struct io_uring_sqe *)0)->hardlink_flags),
                      _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "xattr_flags", offsetof(struct io_uring_sqe, xattr_flags),
                   sizeof(((struct io_uring_sqe *)0)->xattr_flags),
                   _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "msg_ring_flags", offsetof(struct io_uring_sqe, msg_ring_flags),
                      sizeof(((struct io_uring_sqe *)0)->msg_ring_flags),
                      _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "uring_cmd_flags", offsetof(struct io_uring_sqe, uring_cmd_flags),
                       sizeof(((struct io_uring_sqe *)0)->uring_cmd_flags),
                       _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "user_data", offsetof(struct io_uring_sqe, user_data),
                 sizeof(((struct io_uring_sqe *)0)->user_data),
                 _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "buf_index", offsetof(struct io_uring_sqe, buf_index),
                 sizeof(((struct io_uring_sqe *)0)->buf_index),
                 _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "buf_group", offsetof(struct io_uring_sqe, buf_group),
                 sizeof(((struct io_uring_sqe *)0)->buf_group),
                 _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "personality", offsetof(struct io_uring_sqe, personality),
                   sizeof(((struct io_uring_sqe *)0)->personality),
                   _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "splice_fd_in", offsetof(struct io_uring_sqe, splice_fd_in),
                    sizeof(((struct io_uring_sqe *)0)->splice_fd_in),
                    _CFFI_OP(_CFFI_OP_NOOP, 122) },
  { "file_index", offsetof(struct io_uring_sqe, file_index),
                  sizeof(((struct io_uring_sqe *)0)->file_index),
                  _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "addr_len", offsetof(struct io_uring_sqe, addr_len),
                sizeof(((struct io_uring_sqe *)0)->addr_len),
                _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "__pad3", offsetof(struct io_uring_sqe, __pad3),
              sizeof(((struct io_uring_sqe *)0)->__pad3),
              _CFFI_OP(_CFFI_OP_NOOP, 140) },
  { "addr3", offsetof(struct io_uring_sqe, addr3),
             sizeof(((struct io_uring_sqe *)0)->addr3),
             _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "__pad2", offsetof(struct io_uring_sqe, __pad2),
              sizeof(((struct io_uring_sqe *)0)->__pad2),
              _CFFI_OP(_CFFI_OP_NOOP, 155) },
  { "cmd", offsetof(struct io_uring_sqe, cmd),
           sizeof(((struct io_uring_sqe *)0)->cmd),
           _CFFI_OP(_CFFI_OP_NOOP, 144) },
  { "iov_base", offsetof(struct iovec, iov_base),
                sizeof(((struct iovec *)0)->iov_base),
                _CFFI_OP(_CFFI_OP_NOOP, 69) },
  { "iov_len", offsetof(struct iovec, iov_len),
               sizeof(((struct iovec *)0)->iov_len),
               _CFFI_OP(_CFFI_OP_NOOP, 70) },
  { "msg_name", offsetof(struct msghdr, msg_name),
                sizeof(((struct msghdr *)0)->msg_name),
                _CFFI_OP(_CFFI_OP_NOOP, 69) },
  { "msg_namelen", offsetof(struct msghdr, msg_namelen),
                   sizeof(((struct msghdr *)0)->msg_namelen),
                   _CFFI_OP(_CFFI_OP_NOOP, 13) },
  { "msg_iov", offsetof(struct msghdr, msg_iov),
               sizeof(((struct msghdr *)0)->msg_iov),
               _CFFI_OP(_CFFI_OP_NOOP, 132) },
  { "msg_iovlen", offsetof(struct msghdr, msg_iovlen),
                  sizeof(((struct msghdr *)0)->msg_iovlen),
                  _CFFI_OP(_CFFI_OP_NOOP, 70) },
  { "msg_control", offsetof(struct msghdr, msg_control),
                   sizeof(((struct msghdr *)0)->msg_control),
                   _CFFI_OP(_CFFI_OP_NOOP, 69) },
  { "msg_controllen", offsetof(struct msghdr, msg_controllen),
                      sizeof(((struct msghdr *)0)->msg_controllen),
                      _CFFI_OP(_CFFI_OP_NOOP, 70) },
  { "msg_flags", offsetof(struct msghdr, msg_flags),
                 sizeof(((struct msghdr *)0)->msg_flags),
                 _CFFI_OP(_CFFI_OP_NOOP, 29) },
  { "sa_family", offsetof(struct sockaddr, sa_family),
                 sizeof(((struct sockaddr *)0)->sa_family),
                 _CFFI_OP(_CFFI_OP_NOOP, 158) },
  { "sa_data", offsetof(struct sockaddr, sa_data),
               sizeof(((struct sockaddr *)0)->sa_data),
               _CFFI_OP(_CFFI_OP_NOOP, 119) },
  { "sin_family", offsetof(struct sockaddr_in, sin_family),
                  sizeof(((struct sockaddr_in *)0)->sin_family),
                  _CFFI_OP(_CFFI_OP_NOOP, 158) },
  { "sin_port", offsetof(struct sockaddr_in, sin_port),
                sizeof(((struct sockaddr_in *)0)->sin_port),
                _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "sin_addr", offsetof(struct sockaddr_in, sin_addr),
                sizeof(((struct sockaddr_in *)0)->sin_addr),
                _CFFI_OP(_CFFI_OP_NOOP, 126) },
  { "sin_zero", offsetof(struct sockaddr_in, sin_zero),
                sizeof(((struct sockaddr_in *)0)->sin_zero),
                _CFFI_OP(_CFFI_OP_NOOP, 151) },
  { "sin6_family", offsetof(struct sockaddr_in6, sin6_family),
                   sizeof(((struct sockaddr_in6 *)0)->sin6_family),
                   _CFFI_OP(_CFFI_OP_NOOP, 158) },
  { "sin6_port", offsetof(struct sockaddr_in6, sin6_port),
                 sizeof(((struct sockaddr_in6 *)0)->sin6_port),
                 _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "sin6_flowinfo", offsetof(struct sockaddr_in6, sin6_flowinfo),
                     sizeof(((struct sockaddr_in6 *)0)->sin6_flowinfo),
                     _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "sin6_addr", offsetof(struct sockaddr_in6, sin6_addr),
                 sizeof(((struct sockaddr_in6 *)0)->sin6_addr),
                 _CFFI_OP(_CFFI_OP_NOOP, 125) },
  { "sin6_scope_id", offsetof(struct sockaddr_in6, sin6_scope_id),
                     sizeof(((struct sockaddr_in6 *)0)->sin6_scope_id),
                     _CFFI_OP(_CFFI_OP_NOOP, 142) },
  { "sun_family", offsetof(struct sockaddr_un, sun_family),
                  sizeof(((struct sockaddr_un *)0)->sun_family),
                  _CFFI_OP(_CFFI_OP_NOOP, 158) },
  { "sun_path", offsetof(struct sockaddr_un, sun_path),
                sizeof(((struct sockaddr_un *)0)->sun_path),
                _CFFI_OP(_CFFI_OP_NOOP, 117) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "__kernel_timespec", 124, _CFFI_F_CHECK_FIELDS,
    sizeof(struct __kernel_timespec), offsetof(struct _cffi_align_struct___kernel_timespec, y), 0, 2 },
  { "in6_addr", 125, 0,
    sizeof(struct in6_addr), offsetof(struct _cffi_align_struct_in6_addr, y), 2, 1 },
  { "in_addr", 126, _CFFI_F_CHECK_FIELDS,
    sizeof(struct in_addr), offsetof(struct _cffi_align_struct_in_addr, y), 3, 1 },
  { "io_uring", 127, _CFFI_F_CHECK_FIELDS,
    sizeof(struct io_uring), offsetof(struct _cffi_align_struct_io_uring, y), 4, 9 },
  { "io_uring_cq", 128, _CFFI_F_CHECK_FIELDS,
    sizeof(struct io_uring_cq), offsetof(struct _cffi_align_struct_io_uring_cq, y), 13, 12 },
  { "io_uring_cqe", 129, _CFFI_F_CHECK_FIELDS,
    sizeof(struct io_uring_cqe), offsetof(struct _cffi_align_struct_io_uring_cqe, y), 25, 4 },
  { "io_uring_sq", 130, _CFFI_F_CHECK_FIELDS,
    sizeof(struct io_uring_sq), offsetof(struct _cffi_align_struct_io_uring_sq, y), 29, 15 },
  { "io_uring_sqe", 131, 0,
    sizeof(struct io_uring_sqe), offsetof(struct _cffi_align_struct_io_uring_sqe, y), 44, 41 },
  { "iovec", 133, _CFFI_F_CHECK_FIELDS,
    sizeof(struct iovec), offsetof(struct _cffi_align_struct_iovec, y), 85, 2 },
  { "msghdr", 134, _CFFI_F_CHECK_FIELDS,
    sizeof(struct msghdr), offsetof(struct _cffi_align_struct_msghdr, y), 87, 7 },
  { "sockaddr", 135, _CFFI_F_CHECK_FIELDS,
    sizeof(struct sockaddr), offsetof(struct _cffi_align_struct_sockaddr, y), 94, 2 },
  { "sockaddr_in", 137, _CFFI_F_CHECK_FIELDS,
    sizeof(struct sockaddr_in), offsetof(struct _cffi_align_struct_sockaddr_in, y), 96, 4 },
  { "sockaddr_in6", 136, _CFFI_F_CHECK_FIELDS,
    sizeof(struct sockaddr_in6), offsetof(struct _cffi_align_struct_sockaddr_in6, y), 100, 5 },
  { "sockaddr_un", 138, _CFFI_F_CHECK_FIELDS,
    sizeof(struct sockaddr_un), offsetof(struct _cffi_align_struct_sockaddr_un, y), 105, 2 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$10", 121, _cffi_prim_int(4, 0),
    "IOSQE_FIXED_FILE_BIT,IOSQE_IO_DRAIN_BIT,IOSQE_IO_LINK_BIT,IOSQE_IO_HARDLINK_BIT,IOSQE_ASYNC_BIT,IOSQE_BUFFER_SELECT_BIT,IOSQE_CQE_SKIP_SUCCESS_BIT" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "__kernel_rwf_t", 29 },
  { "__s32", 122 },
  { "__u16", 139 },
  { "__u32", 142 },
  { "__u64", 78 },
  { "__u8", 143 },
  { "sa_family_t", 158 },
  { "socklen_t", 13 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  61,  /* num_globals */
  14,  /* num_struct_unions */
  1,  /* num_enums */
  8,  /* num_typenames */
  NULL,  /* no includes */
  160,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__liburing(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__liburing(void) { return NULL; }
#  else
     init_liburing(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__liburing(void)
{
  return _cffi_init("uringloop._liburing", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_liburing(void)
{
  _cffi_init("uringloop._liburing", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
